module.exports = defineTest({
	description: 'namespace object import',
	options: {
		input: ['main1.js', 'main2.js']
	}
});
